CallTraceStep

Struct CallTraceStep 

pub struct CallTraceStep {
Show 17 fields pub pc: usize, pub op: OpCode, pub stack: Option<Box<[Uint<256, 4>]>>, pub push_stack: Option<Box<[Uint<256, 4>]>>, pub memory: Option<RecordedMemory>, pub returndata: Bytes, pub gas_remaining: u64, pub gas_refund_counter: u64, pub gas_used: u64, pub gas_cost: u64, pub state_gas_cost: Option<i64>, pub state_gas_reservoir: Option<u64>, pub state_gas_spent: i64, pub storage_change: Option<Box<StorageChange>>, pub status: Option<InstructionResult>, pub immediate_bytes: Option<Bytes>, pub decoded: Option<Box<DecodedTraceStep>>,
}
Represents a tracked call step during execution

Fields

pc: usize

Program counter before step execution

op: OpCode

Opcode to be executed

stack: Option<Box<[Uint<256, 4>]>>

Stack before step execution

push_stack: Option<Box<[Uint<256, 4>]>>

The new stack items placed by this step if any

memory: Option<RecordedMemory>

Memory before step execution.

This will be None only if memory capture is disabled.

returndata: Bytes

Returndata before step execution

gas_remaining: u64

Remaining gas before step execution

gas_refund_counter: u64

Gas refund counter before step execution

gas_used: u64

Total gas used before step execution

gas_cost: u64

Gas cost of step execution

state_gas_cost: Option<i64>

Net state-gas change caused by this step.

state_gas_reservoir: Option<u64>

State-gas reservoir before this step.

state_gas_spent: i64

State-gas spent before this step, used to calculate state_gas_cost.

storage_change: Option<Box<StorageChange>>

Change of the contract state after step execution (effect of the SLOAD/SSTORE instructions)

status: Option<InstructionResult>

Final status of the step

This is set after the step was executed.

immediate_bytes: Option<Bytes>

Immediate bytes of the step

decoded: Option<Box<DecodedTraceStep>>

Optional complementary decoded step data.

Implementations



impl CallTraceStep

pub fn decoded_mut(&mut self) -> &mut DecodedTraceStep

Returns DecodedTraceStep from CallTraceStep.